@@ -74,12 +74,12 @@ class MsgFields(ConstantDict):
     PORT_PROTO = "portproto"
     PORT_NUM = "portnum"
     PHYSICAL_ADDRESS = "phyaddr"
-    SCREENSHOT = "screenshot"
     SPIDER = "spider"
     SPIDER_TIMEOUT = "spidertimeout"
     STATUS = "status"
     URL = "url"
     URL_CONTENT = "urlcontent"
+    URL_SCREENSHOT = "urlscreenshot"
     URL_SPIDER_CONTENT = "urlspidercontent"
     WEB_FINGERPRINTS = "webfingerprints"
     WHOIS = "whois"
@@ -124,6 +124,7 @@ class MsgValues(ConstantDict):
     NMAP_STATUS_UP = "up"
 
     URL_MANIFEST = "urlmani"
+    URL_SCREENSHOT_FILE = "urlshot"
 
 
 class MsgErrs(ConstantDict):
@@ -149,5 +150,6 @@ class MsgErrs(ConstantDict):
 
     URL_INVALID = "URL_INVALID::{0}"
     URL_TIMEOUT = "URL_TIMEOUT::{0}"
+    URL_SCREENSHOT_TIMEOUT = "URL_SCREENSHOT_TIMEOUT::{0}"
     URL_SPIDER_TIMEOUT = "URL_SPIDER_TIMEOUT::{0}"
     URL_CONN_ERROR = "URL_CONN_ERROR::{0}"
